@@ -2,6 +2,7 @@
 
 from .acfun import *
 from .bilibili import *
+from .blip import *
 from .cntv import *
 from .dailymotion import *
 from .douban import *
@@ -23,6 +24,7 @@ from .sohu import *
 from .soundcloud import *
 from .tudou import *
 from .tumblr import *
+from .vid48 import *
 from .vimeo import *
 from .w56 import *
 from .xiami import *
